# This file was auto-generated by Fern from our API Definition.

import typing

DocumentsCreateRequestBodyOneValue = typing.Union[bool, typing.Dict[str, typing.Optional[typing.Any]], float, int, str]
