# This file was auto-generated by Fern from our API Definition.

import typing

from .bare_output import BareOutput
from .baseline import Baseline
from .default_output import DefaultOutput
from .html_2_text import Html2Text

TrafilaturaOutputTrafilaturaType = typing.Union[BareOutput, Baseline, DefaultOutput, Html2Text]
