# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .document_data_value import DocumentDataValue
from .identity import Identity


class Document(UncheckedBaseModel):
    document_id: typing.Optional[str] = None
    data: typing.Optional[typing.Dict[str, typing.Optional[DocumentDataValue]]] = None
    document_data_id: typing.Optional[str] = None
    created_at: typing.Optional[dt.datetime] = None
    last_updated_at: typing.Optional[dt.datetime] = None
    created_by: Identity
    last_updated_by: Identity
    revision_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
