# This file was auto-generated by Fern from our API Definition.

import typing

from .http import Http
from .playwright import Playwright

SinglePageCrawlerSettingsInputScraper = typing.Union[Http, Playwright]
