# This file was auto-generated by Fern from our API Definition.

import typing

ColumnType = typing.Union[
    typing.Literal["checkbox", "json", "number", "select", "text-long", "text-short", "url", "markdown"], typing.Any
]
