# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.collection_service_handlers_get_table_response import CollectionServiceHandlersGetTableResponse
from ...types.schema_response import SchemaResponse

TablesGetSchemaResponse = typing.Union[CollectionServiceHandlersGetTableResponse, SchemaResponse]
