# This file was auto-generated by Fern from our API Definition.

import typing

from .custom import Custom
from .readability import Readability
from .trafilatura_output import TrafilaturaOutput

SinglePageCrawlerSettingsOutputTextExtractor = typing.Union[Custom, Readability, TrafilaturaOutput]
