# This file was auto-generated by Fern from our API Definition.

import typing

from .mark_down_with_context import MarkDownWithContext
from .markdown_splitter_config import MarkdownSplitterConfig
from .paragraph_splitter_config import ParagraphSplitterConfig
from .recursive_splitter_config import RecursiveSplitterConfig
from .sentence_splitter_config import SentenceSplitterConfig

SourceSyncWebsiteSettingsSplitter = typing.Union[
    MarkdownSplitterConfig,
    RecursiveSplitterConfig,
    SentenceSplitterConfig,
    ParagraphSplitterConfig,
    MarkDownWithContext,
]
