# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SourceArchetype(UncheckedBaseModel):
    archetype_id: str = pydantic.Field()
    """
    The unique identifier for this source archetype
    """

    display_name: str = pydantic.Field()
    """
    The human readable name for this source archetype
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    A description of this source archetype
    """

    schedulable: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Wether or not this Source can be schedule to run at an interval
    """

    img_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    A URL to an image representing this source archetype
    """

    input_schema: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    The input schema for this source archetype
    """

    integrated_service_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Determines if the SourceSync is a IntegratedService
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
